@@ -2,12 +2,11 @@
 #
 # @package      hubzero-submit-distributor
 # @file         Scripts/condor/killbatchjob.sh
-# @author       Steve Clark <clarks@purdue.edu>
-# @copyright    Copyright 2004-2011 Purdue University. All rights reserved.
+# @author       Steven Clark <clarks@purdue.edu>
+# @copyright    Copyright 2004-2012 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2004-2011 Purdue University
-# All rights reserved.
+# Copyright (c) 2004-2012 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -25,7 +24,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-# HUBzero is a registered trademark of Purdue University.
+# HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
 if [ $# -ne 2 ] ; then
    echo usage: $0 jobId jobClass
@@ -37,6 +36,11 @@ case $2 in
       condor_rm $1
       exitStatus=$?
       ;;
+   PEGASUS)
+      export CONDOR_CONFIG=/var/condor/Grid/etc/condor_config
+      /var/condor/Condor/@CONDORVERSION@/bin/condor_rm $1
+      exitStatus=$?
+      ;;
    *)
       echo "Invalid job class $2"
       exitStatus=23
