@@ -2,12 +2,11 @@
 #
 # @package      hubzero-submit-distributor
 # @file         monitorJobR.py
-# @author       Steve Clark <clarks@purdue.edu>
-# @copyright    Copyright 2004-2011 Purdue University. All rights reserved.
+# @author       Steven Clark <clarks@purdue.edu>
+# @copyright    Copyright (c) 2004-2012 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2004-2011 Purdue University
-# All rights reserved.
+# Copyright (c) 2004-2012 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -25,7 +24,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-# HUBzero is a registered trademark of Purdue University.
+# HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
 # ----------------------------------------------------------------------
 #  monitorJobR.py
@@ -35,7 +34,7 @@
 import sys
 import time
 
-from RemoteJobMonitor import RemoteJobMonitor
+from hubzero.submit.RemoteJobMonitor import RemoteJobMonitor
 
 JOBMONITORHOST = ""
 JOBMONITORPORT = 5727
@@ -78,7 +77,7 @@ def monitorJobR():
                if not status in reportedJobs:
                   reportedJobs[status] = {}
                try:
-                  reportedJobs[status][int(float(jobId))] = state
+                  reportedJobs[status][jobId] = state
                except:
                   print "job poorly formatted: %s" % (job)
 
@@ -88,7 +87,7 @@ def monitorJobR():
                jobIds = reportedJobs[status].keys()
                jobIds.sort()
                for jobId in jobIds:
-                  print "         %d  %s" % (jobId,reportedJobs[status][jobId])
+                  print "         %s  %s" % (jobId,reportedJobs[status][jobId])
 
             del reportedJobs
    else:
@@ -99,3 +98,4 @@ def monitorJobR():
 if __name__ == '__main__':
    monitorJobR()
 
+
